@@ -2,7 +2,7 @@ package Mojo::PDF;
 
 use Mojo::Base -base;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.002001'; # VERSION
 
 use Carp qw/croak/;
 $Carp::Internal{ (__PACKAGE__) }++;
@@ -12,6 +12,8 @@ use List::AllUtils qw/sum/;
 use Mojo::PDF::Primitive::Table;
 use namespace::clean;
 
+$SIG{'__WARN__'} = sub { warn @_ unless caller eq 'PDF::Reuse'; };
+
 has [qw/_x _y _line_height/] => 0;
 has [qw/_cur_font  _cur_size  _cur_color/];
 has _fonts => sub { +{} };
@@ -108,6 +110,8 @@ sub size {
 
 sub color {
     my $self = shift;
+    @_ = @{$_[0]} if @_ == 1 and ref $_[0] eq 'ARRAY';
+
     my ( $r, $g, $b )
         = @_ == 0 ? (0, 0, 0) # default to black
             : @_ == 1
@@ -136,11 +140,11 @@ sub table {
 
     my $t = Mojo::PDF::Primitive::Table->new(
         pdf => $self,
-        map +( $conf{$_} ? ( $_ => $conf{$_} ) : () ),
-            qw/data  min_width  at  border  row_height  str_width_mult/,
+        %conf,
     );
 
-    $t->draw;
+    my @overflow = $t->draw;
+    return \@overflow if $conf{max_height};
 
     $self;
 }
@@ -168,7 +172,10 @@ sub text {
 }
 
 sub page {
+    my $self = shift;
     prPage;
+
+    $self;
 }
 
 sub end {
@@ -190,6 +197,7 @@ sub _line {
 sub _str_width {
     my $self = shift;
     my $str = shift;
+
     return prStrWidth(
         $str,
         $self->_cur_font//'Helvetica',
@@ -242,12 +250,10 @@ Mojo::PDF - Generate PDFs with the goodness of Mojo!
         # Render a table
         ->font('galaxie_it')->size(8)->color
         ->table(
-            at     => [20.4, 268],
-            width  => 571.2,
-            border => [.5, '#CFE3EF'],
-            data   => [
+            at        => [20.4, 268],
+            data      => [
                 [ qw{Product  Description Qty  Price  U/M} ],
-                @$data,
+                @data,
             ],
         )
 
@@ -282,8 +288,7 @@ of the PDF you want to generate.
 
     $p->end;
 
-Finish rendering your PDF and save it. Currently, you cannot reuse the same
-C<Mojo::PDF> object to create more than one PDF.
+Finish rendering your PDF and save it.
 
 =head2 C<add_fonts>
 
@@ -293,15 +298,15 @@ C<Mojo::PDF> object to create more than one PDF.
     );
 
 Adds TTF fonts to the document. Key/value pairs specify the arbitrary name
-of the font (for use with L<font> and the path to the TTF file.
+of the font (for you to use with L</font>) and the path to the TTF file.
 
-You cannot use any of the names of the L<DEFAULT FONTS> for your fonts.
+You cannot use any of the names of the L</DEFAULT FONTS> for your custom fonts.
 
 =head2 C<color>
 
     $pdf->color(.5, .5, .3);
     $pdf->color('#abcdef');
-    $pdf->color('#ccc');   # same as #cccccc
+    $pdf->color('#abc');   # same as #aabbcc
     $pdf->color;           # same as #000
 
 Specifies active color. Takes either an RGB tuple or a hex colour. Defaults
@@ -313,8 +318,8 @@ to black.
 
     $pdf->font('galaxie');
 
-Sets active font family. Takes the name of either one of the L<DEFAULT FONTS>
-or one of the custom fonts included with L<add_fonts>
+Sets active font family. Takes the name of either one of the L</DEFAULT FONTS>
+or one of the custom fonts included with L</add_fonts>
 
 =head2 C<mixin>
 
@@ -322,16 +327,17 @@ or one of the custom fonts included with L<add_fonts>
 
     $pdf->mixin('template.pdf', 3);
 
-Adds a page from an existing PDF to your currently active page. Takes one
-mandatory argument, the filename of the PDF to include. An optional argument
-specifies the page number to include (starting from 1), which defaults to
-the first page.
+Adds a page from an existing PDF to your currently active page, so you
+can use it as a template and render additional things on it. Takes one
+mandatory argument, the filename of the PDF to include. An optional second
+argument specifies the page number to include (starting from 1),
+which defaults to the first page.
 
 =head2 C<page>
 
-    $p->page;
+    $pdf->page;
 
-Add a new blank page to your document.
+Add a new blank page to your document and sets it as the currently active page.
 
 =head2 C<size>
 
@@ -339,21 +345,23 @@ Add a new blank page to your document.
 
     $pdf->size; # set to 12
 
-Specifies active font size in points. Defaults to 12 points.
+Specifies active font size in points. Defaults to C<12> points.
 
 =head2 C<table>
 
-    $t->table(
-        at     => [20.4, 268],
-        width  => 571.2,
-        border => [.5, '#CFE3EF'],
-        data   => [
+    $pdf->table(
+        at        => [20.4, 268],
+        data      => [
             [ qw{Product  Description Qty  Price  U/M} ],
             @$data,
         ],
 
         #Optional:
-        row_height => 24,
+        border         => [.5, '#CFE3EF'],
+        header         => 'galaxie_bold',
+        max_height     => 744,
+        min_width      => 571.2,
+        row_height     => 24,
         str_width_mult => 1.1,
     );
 
@@ -365,36 +373,63 @@ Render a table on the current page. Takes these arguments:
 
 An arrayref with X and Y point values of the table's top, left corner.
 
-=head3 C<width>
-
-    min_width => 571.2,
-
-Table's minimum width in points. The largest column will be widened
-to make the table at least this wide.
-
-=head3 C<border>
-
-    border => [.5, '#CFE3EF'],
-
-Takes an arrayref with the width (in points) and colour of the table's borders.
-Color allows the same values as L<color> method.
-
 =head3 C<data>
 
-    data   => [
+    data => [
         [ qw{Product  Description Qty  Price  U/M} ],
         @$data,
     ],
 
 An arrayref of rows, each of which is an arrayref of strings representing
-table cell values.
+table cell values. Setting L</header> will render first row as a table header.
+Cells that are C<undef>/empty string will not be rendered.
+
+=head3 C<border>
+
+    border => [.5, '#CFE3EF'],
+
+B<Optional>. Takes an arrayref with the width (in points) and colour of
+the table's borders. Color allows the same values as L</color> method.
+B<Defaults to:> C<[.5, '#ccc']>
+
+=head3 C<header>
+
+    header => 'galaxie_bold',
+
+B<Optional>. Takes the same value as L</font>. If set, the first row
+of C</data> will be used as table header, rendered centered using
+C<header> font. B<Not set by default.>
+
+=head3 C<max_height>
+
+    {
+        $data = $pdf->table(
+            max_height => 744,
+            data       => $data,
+            at         => [20.4, 50],
+        );
+
+        @$data and $pdf->page and redo;
+    }
+
+B<Optional>. B<ALTERS RETURN VALUE OF C<table> METHOD>. Specifies the maximum
+height of the table. Specifying this option makes C<table> method return
+an arrayref of rows that did not fit into the table. You can use that to
+add a new page and continue rendering the overflown data.
+
+=head3 C<min_width>
+
+    min_width => 571.2,
+
+B<Optional>. Table's minimum width in points (zero by default).
+The largest column will be widened to make the table at least this wide.
 
 =head3 C<row_height>
 
     row_height => 24,
 
 B<Optional>. Specifies the height of a row, in points. Defaults to
-1.4 times the current font size.
+1.4 times the current L<font size|/size>.
 
 =head3 C<str_width_mult>
 
@@ -413,14 +448,15 @@ detected character width.
     $p->text('Lorem ipsum dolor sit amet, ', 20 );
     $p->text('consectetur adipiscing elit!');
 
-Render text with the currently active L<font>, L<size>, and L<color>.
+Render text with the currently active L</font>, L</size>, and L</color>.
 C<$alignment> specifies how to align the string horizontally on the C<$x>
 point; valid values are C<left> (default), C<center>, and C<right>.
 C<$rotation> is the rotation of the text in degrees.
 
-Subsequent calls to L<text> can omit C<$x> and C<$y> values with these effects:
-omit both to continue rendering where previous L<text> finished; omit just
-C<$y>, to render on the next line from previous call to L<text>.
+Subsequent calls to C<text> can omit C<$x> and C<$y> values with
+these effects: omit both to continue rendering where previous C<text>
+finished; omit just C<$y>, to render on the next line from previous call
+to C<text>.
 
 =head1 DEFAULT FONTS
 
@@ -444,7 +480,7 @@ These fonts are available by default:
     Symbol
     ZapfDingbats
 
-You can use their abbreviate names:
+You can use their abbreviated names:
 
     TR
     TB
